@@ -377,6 +377,11 @@ def test_parse_extension():
     extend Foo {
       optional int32 bar = 101;
     }
+
+    extend Foo_Comment {
+      // This is a comment.
+      optional int32 bar = 101;
+    }
     """
     result = Parser().parse(text)
     expected = ast.File(
@@ -402,6 +407,19 @@ def test_parse_extension():
                     ),
                 ],
             ),
+            ast.Extension(
+                typeName="Foo_Comment",
+                elements=[
+                    ast.Comment(text="// This is a comment."),
+                    ast.Field(
+                        name="bar",
+                        number=101,
+                        cardinality=ast.FieldCardinality.OPTIONAL,
+                        type="int32",
+                        options=[],
+                    ),
+                ],
+            ),
         ],
     )
     assert result == expected
@@ -748,6 +766,10 @@ def test_parse_service():
             option (my_method_option).foo = 567;
             option (my_method_option).bar = "Some string";
         }
+        rpc MyMethod_Semicolon(RequestType) returns(ResponseType) {
+            option (my_method_option).foo = 567;
+            option (my_method_option).bar = "Some string";
+        };
     }
 
     service ExampleEmptyService {}
@@ -788,6 +810,17 @@ def test_parse_service():
                             ),
                         ],
                     ),
+                    ast.Method(
+                        name="MyMethod_Semicolon",
+                        input_type=ast.MessageType(type="RequestType"),
+                        output_type=ast.MessageType(type="ResponseType"),
+                        elements=[
+                            ast.Option(name="(my_method_option).foo", value="567"),
+                            ast.Option(
+                                name="(my_method_option).bar", value="Some string"
+                            ),
+                        ],
+                    ),
                 ],
             ),
             ast.Service(
@@ -981,3 +1014,37 @@ def test_parse_comments_in_service():
     )
 
     assert result == expected
+
+
+def test_comments_at_beginning_of_file():
+    text = """
+    // This is a comment
+    syntax = "proto3";
+
+    message ExampleMessage {
+        // Field comment
+        string example_field = 1;
+    }
+    """
+    result = Parser().parse(text)
+
+    expected = ast.File(
+        syntax="proto3",
+        file_elements=[
+            ast.Comment(text="// This is a comment"),
+            ast.Message(
+                name="ExampleMessage",
+                elements=[
+                    ast.Comment(text="// Field comment"),
+                    ast.Field(
+                        name="example_field",
+                        number=1,
+                        type="string",
+                        options=[],
+                    ),
+                ],
+            ),
+        ],
+    )
+
+    assert result == expected
